@@ -1,9 +1,12 @@
 #!/usr/bin/env python3
 import sys
-from ctypes import *
+from ctypes import CDLL, Structure, c_byte, c_char_p, c_void_p, \
+    pointer, string_at
+
 
 def py_str_at(addr):
-    return string_at(addr).decode('UTF-8');
+    return string_at(addr).decode('UTF-8')
+
 
 def main(argv):
     fcs = CDLL("libfreecell-solver.so")
@@ -13,7 +16,8 @@ def main(argv):
 
     board = open(argv.pop(0)).read()
 
-    fcs.freecell_solver_user_solve_board(user,
+    fcs.freecell_solver_user_solve_board(
+        user,
         c_char_p(
            bytes(board, 'UTF-8')
         )
@@ -40,13 +44,17 @@ def main(argv):
     print_state()
 
     while (fcs.freecell_solver_user_get_next_move(user, pointer(move)) == 0):
-        as_string = fcs.freecell_solver_user_move_to_string_w_state(user, move, 0)
+        as_string = fcs.freecell_solver_user_move_to_string_w_state(
+            user, move, 0
+        )
         print("\n%s\n\n" % (py_str_at(as_string)))
         libc.free(as_string)
         print_state()
-    fcs.freecell_solver_user_free(user);
+    fcs.freecell_solver_user_free(user)
+
+
+# ----------------------------------------------------------------------
 
-#----------------------------------------------------------------------
 
 if __name__ == "__main__":
     main(sys.argv[1:])
