@@ -8,12 +8,12 @@
 
 use strict;
 use warnings;
-use Path::Tiny;
+use Path::Tiny qw/ path /;
 
 sub get_time
 {
     my $l = shift;
-    if ($l =~ m{ at (\d+\.\d+)})
+    if ( $l =~ m{ at (\d+\.\d+)} )
     {
         return $1;
     }
@@ -26,11 +26,15 @@ sub get_time
 foreach my $fn (@ARGV)
 {
     my @lines = path($fn)->lines_utf8;
-    if (@ARGV > 1)
+    if ( not @lines )
     {
-        print $fn.':';
+        die qq#File "$fn" is empty.#;
     }
-    print +(get_time($lines[-1]) - get_time($lines[0])), "\n";
+    if ( @ARGV > 1 )
+    {
+        print $fn. ':';
+    }
+    print +( get_time( $lines[-1] ) - get_time( $lines[0] ) ), "\n";
 }
 
 =head1 COPYRIGHT AND LICENSE
